@@ -109,15 +109,25 @@ public:
 		pfont = nullptr;
 	}
 };
-static int FontCharacterSet(Font &f)
-{
-	return reinterpret_cast<FontAndCharacterSet *>(f.GetID())->characterSet;
+
+namespace {
+
+FontAndCharacterSet *AsFontAndCharacterSet(const Font &f) {
+	return reinterpret_cast<FontAndCharacterSet *>(f.GetID());
 }
 
-static QFont *FontPointer(Font &f)
+int FontCharacterSet(const Font &f)
 {
-	return reinterpret_cast<FontAndCharacterSet *>(f.GetID())->pfont;
+	return AsFontAndCharacterSet(f)->characterSet;
 }
+
+QFont *FontPointer(const Font &f)
+{
+	return AsFontAndCharacterSet(f)->pfont;
+}
+
+}
+
 Font::Font() noexcept : fid(nullptr) {}
 Font::~Font()
 {
@@ -1096,6 +1106,11 @@ public:
 		QString path = QString::fromUtf8(modulePath);
 		lib = new QLibrary(path);
 	}
+	// Deleted so DynamicLibraryImpl objects can not be copied
+	DynamicLibraryImpl(const DynamicLibraryImpl &) = delete;
+	DynamicLibraryImpl(DynamicLibraryImpl &&) = delete;
+	DynamicLibraryImpl &operator=(const DynamicLibraryImpl &) = delete;
+	DynamicLibraryImpl &operator=(DynamicLibraryImpl &&) = delete;
 
 	virtual ~DynamicLibraryImpl() {
 		if (lib)
